from .containers import BasicSauce, BookSauce, VideoSauce
from .saucenao_api import SauceNao, AIOSauceNao

__author__ = 'nomnoms12'
__copyright__ = 'Copyright 2020, Taiga.sh Development'
__credits__ = ['nomnoms12', 'FujiMakoto', 'rubinduck', 'spoopcity', 'bakashigure', 'ByteDream', 'trolhamonas']
__license__ = 'GNU General Public License v3.0'
__version__ = '2.4.0'
__maintainer__ = 'nomnoms12'
__email__ = 'alexander.ign0918@gmail.com'
__status__ = 'Production'
